@@ -24,18 +24,3 @@ FontInfo = namedtuple(
 GlyphComp = namedtuple('GlyphComp', ['glyphs', 'xforms', 'bbox'])
 Xform = namedtuple('Xform', ['a', 'b', 'c', 'd', 'e', 'f', 'match'])
 Symbols = namedtuple('Symbols', ['word', 'symbols', 'width', 'xmin', 'ymin', 'ymax'])
-
-
-@dataclass
-class FontFeatures:
-    kern: bool = True   # Horizontal kerning
-    liga: bool = True   # Ligatures (combine fi, for example)
-    calt: bool = True   # Contextual alternatives
-    clig: bool = True   # Contextual ligatures
-    salt: bool = False  # Stylistic alternatives (apply all or nothing)
-    dlig: bool = False  # Discretionary ligatures
-    hlig: bool = False  # Historical ligatures
-    c2sc: bool = False  # Small Capitals from Capitals
-    frac: bool = False  # Fractions
-    zero: bool = False  # Zeros with slash
-    ssty: bool = False  # Math script style alternates
